==> g-plugin-html-renderer-1.0.12.tgz: package/es/HTMLRenderingPlugin.js <==
import { __decorate, __metadata } from "tslib";
import { inject, singleton } from 'mana-syringe';
import { SHAPE, RenderingPluginContribution, ContextService, PARSED_COLOR_TYPE, RenderingContext, ElementEvent } from '@antv/g';
import { isString } from '@antv/util';
var HTML_PREFIX = 'g-html-';

var HTMLRenderingPlugin =
/** @class */
function () {
  function HTMLRenderingPlugin() {}

  HTMLRenderingPlugin_1 = HTMLRenderingPlugin;

  HTMLRenderingPlugin.prototype.apply = function (renderingService) {
    var _this = this;

    var handleMounted = function handleMounted(e) {
      var object = e.target;

      if (object.nodeName === SHAPE.HTML) {
        var innerHTML = object.parsedStyle.innerHTML;
        var existedId = HTML_PREFIX + object.entity;

        var $container = _this.contextService.getDomElement().parentNode;

        if ($container) {
          var $existedElement = $container.querySelector('#' + existedId);

          if (!$existedElement) {
            var $div = document.createElement('div');
            object.parsedStyle.$el = $div;
            $div.id = existedId;

            if (isString(innerHTML)) {
              $div.innerHTML = innerHTML;
            } else {
              $div.appendChild(innerHTML);
            }

            $container.appendChild($div);
          }
        }
      }
    };

    var handleUnmounted = function handleUnmounted(e) {
      var object = e.target;

      if (object.nodeName === SHAPE.HTML) {
        var existedId = HTML_PREFIX + object.entity;

        var $container = _this.contextService.getDomElement().parentNode;

        if ($container) {
          var $existedElement = $container.querySelector('#' + existedId);

          if ($existedElement) {
            $container.removeChild($existedElement);
          }
        }
      }
    };

    renderingService.hooks.init.tap(HTMLRenderingPlugin_1.tag, function () {
      _this.renderingContext.root.addEventListener(ElementEvent.MOUNTED, handleMounted);

      _this.renderingContext.root.addEventListener(ElementEvent.UNMOUNTED, handleUnmounted);
    });
    renderingService.hooks.destroy.tap(HTMLRenderingPlugin_1.tag, function () {
      _this.renderingContext.root.removeEventListener(ElementEvent.MOUNTED, handleMounted);

      _this.renderingContext.root.removeEventListener(ElementEvent.UNMOUNTED, handleUnmounted);
    });
    renderingService.hooks.render.tap(HTMLRenderingPlugin_1.tag, function (object) {
      if (object.nodeName === SHAPE.HTML) {
        var existedId = HTML_PREFIX + object.entity;

        var $container = _this.contextService.getDomElement().parentNode;

        if ($container) {
          var $existedElement = $container.querySelector('#' + existedId);

          _this.updateCSSStyle($existedElement, object.parsedStyle, object);
        }
      }
    });
  };

  HTMLRenderingPlugin.prototype.updateCSSStyle = function ($el, parsedStyle, object) {
    var _a = parsedStyle.zIndex,
        zIndex = _a === void 0 ? 0 : _a,
        _b = parsedStyle.visibility,
        visibility = _b === void 0 ? 'visible' : _b,
        _c = parsedStyle.opacity,
        opacity = _c === void 0 ? 1 : _c,
        fill = parsedStyle.fill,
        _d = parsedStyle.lineWidth,
        lineWidth = _d === void 0 ? 0 : _d,
        lineDash = parsedStyle.lineDash,
        stroke = parsedStyle.stroke,
        anchor = parsedStyle.anchor,
        _e = parsedStyle.width,
        width = _e === void 0 ? 0 : _e,
        _f = parsedStyle.height,
        height = _f === void 0 ? 0 : _f,
        _g = parsedStyle.style,
        initialStyle = _g === void 0 ? '' : _g,
        _h = parsedStyle.className,
        className = _h === void 0 ? '' : _h;
    var style = {}; // use absolute position

    style.position = 'absolute';
    style.top = 0;
    style.left = 0;
    style.width = width + "px";
    style.height = height + "px"; // use transform

    style.transform = "matrix3d(" + object.getWorldTransform().join(',') + ")";

    if (anchor) {
      style.transform += " translate(" + anchor[0] * 100 + "%, " + anchor[0] * 100 + "%)";
    } // use unparsed transform origin


    if (object.style.transformOrigin) {
      style['transform-origin'] = object.style.transformOrigin;
    } // z-index


    style['z-index'] = zIndex; // visibility

    style.visibility = visibility; // opacity

    style.opacity = opacity; // backgroundColor

    if (fill) {
      var color = '';

      if (fill.type === PARSED_COLOR_TYPE.Constant) {
        color = fill.formatted;
      } else if (fill.type === PARSED_COLOR_TYPE.LinearGradient) {
        var steps = fill.value.steps.map(function (cur) {
          //  ['0', '#ffffff'],
          return cur[1] + " " + Number(cur[0]) * 100 + "%";
        }).join(','); // @see https://developer.mozilla.org/en-US/docs/Web/CSS/gradient/linear-gradient()

        color = "linear-gradient(to right, " + steps + ");";
      } else if (fill.type === PARSED_COLOR_TYPE.RadialGradient) {} else if (fill.type === PARSED_COLOR_TYPE.Pattern) {}

      style.background = color;
    } // border


    style['border-width'] = lineWidth + "px";

    if (stroke && stroke.type === PARSED_COLOR_TYPE.Constant) {
      style['border-color'] = stroke.formatted;
      style['border-style'] = 'solid';
    }

    if (lineDash) {
      style['border-style'] = 'dashed';
    } // filters


    if (object.style.filter) {
      // use unparsed filter directly
      style.filter = object.style.filter;
    }

    if (className) {
      if (Array.isArray(className)) {
        className.forEach(function (c) {
          $el.classList.add(c);
        });
      } else {
        $el.classList.add(className);
      }
    }

    $el.setAttribute('style', Object.keys(style).map(function (key) {
      return key + ":" + style[key];
    }).join(';') + initialStyle);
  };

  var HTMLRenderingPlugin_1;
  HTMLRenderingPlugin.tag = 'HTMLRenderingPlugin';

  __decorate([inject(ContextService), __metadata("design:type", Object)], HTMLRenderingPlugin.prototype, "contextService", void 0);

  __decorate([inject(RenderingContext), __metadata("design:type", Object)], HTMLRenderingPlugin.prototype, "renderingContext", void 0);

  HTMLRenderingPlugin = HTMLRenderingPlugin_1 = __decorate([singleton({
    contrib: RenderingPluginContribution
  })], HTMLRenderingPlugin);
  return HTMLRenderingPlugin;
}();

export { HTMLRenderingPlugin };

==> g-plugin-html-renderer-1.0.14.tgz: package/es/HTMLRenderingPlugin.js <==
import { __decorate, __metadata } from "tslib";
import { inject, singleton } from 'mana-syringe';
import { Shape, RenderingPluginContribution, ContextService, PARSED_COLOR_TYPE, RenderingContext, ElementEvent } from '@antv/g';
import { isString } from '@antv/util';
var HTML_PREFIX = 'g-html-';

var HTMLRenderingPlugin =
/** @class */
function () {
  function HTMLRenderingPlugin() {}

  HTMLRenderingPlugin_1 = HTMLRenderingPlugin;

  HTMLRenderingPlugin.prototype.apply = function (renderingService) {
    var _this = this;

    var handleMounted = function handleMounted(e) {
      var object = e.target;

      if (object.nodeName === Shape.HTML) {
        var innerHTML = object.parsedStyle.innerHTML;
        var existedId = HTML_PREFIX + object.entity;

        var $container = _this.contextService.getDomElement().parentNode;

        if ($container) {
          var $existedElement = $container.querySelector('#' + existedId);

          if (!$existedElement) {
            var $div = document.createElement('div');
            object.parsedStyle.$el = $div;
            $div.id = existedId;

            if (isString(innerHTML)) {
              $div.innerHTML = innerHTML;
            } else {
              $div.appendChild(innerHTML);
            }

            $container.appendChild($div);
          }
        }
      }
    };

    var handleUnmounted = function handleUnmounted(e) {
      var object = e.target;

      if (object.nodeName === Shape.HTML) {
        var existedId = HTML_PREFIX + object.entity;

        var $container = _this.contextService.getDomElement().parentNode;

        if ($container) {
          var $existedElement = $container.querySelector('#' + existedId);

          if ($existedElement) {
            $container.removeChild($existedElement);
          }
        }
      }
    };

    renderingService.hooks.init.tap(HTMLRenderingPlugin_1.tag, function () {
      _this.renderingContext.root.addEventListener(ElementEvent.MOUNTED, handleMounted);

      _this.renderingContext.root.addEventListener(ElementEvent.UNMOUNTED, handleUnmounted);
    });
    renderingService.hooks.destroy.tap(HTMLRenderingPlugin_1.tag, function () {
      _this.renderingContext.root.removeEventListener(ElementEvent.MOUNTED, handleMounted);

      _this.renderingContext.root.removeEventListener(ElementEvent.UNMOUNTED, handleUnmounted);
    });
    renderingService.hooks.render.tap(HTMLRenderingPlugin_1.tag, function (object) {
      if (object.nodeName === Shape.HTML) {
        var existedId = HTML_PREFIX + object.entity;

        var $container = _this.contextService.getDomElement().parentNode;

        if ($container) {
          var $existedElement = $container.querySelector('#' + existedId);

          _this.updateCSSStyle($existedElement, object.parsedStyle, object);
        }
      }
    });
  };

  HTMLRenderingPlugin.prototype.updateCSSStyle = function ($el, parsedStyle, object) {
    var _a = parsedStyle.zIndex,
        zIndex = _a === void 0 ? 0 : _a,
        _b = parsedStyle.visibility,
        visibility = _b === void 0 ? 'visible' : _b,
        _c = parsedStyle.opacity,
        opacity = _c === void 0 ? 1 : _c,
        fill = parsedStyle.fill,
        lineWidth = parsedStyle.lineWidth,
        lineDash = parsedStyle.lineDash,
        stroke = parsedStyle.stroke,
        anchor = parsedStyle.anchor,
        width = parsedStyle.width,
        height = parsedStyle.height,
        _d = parsedStyle.style,
        initialStyle = _d === void 0 ? '' : _d,
        _e = parsedStyle.className,
        className = _e === void 0 ? '' : _e;
    var contentWidth = 0;
    var contentHeight = 0;
    var widthUnit = width.unit,
        widthValue = width.value;
    var heightUnit = height.unit,
        heightValue = height.value;

    if (widthUnit === '' || widthUnit === 'px') {
      contentWidth = widthValue;
    }

    if (heightUnit === '' || heightUnit === 'px') {
      contentHeight = heightValue;
    }

    var style = {}; // use absolute position

    style.position = 'absolute';
    style.top = 0;
    style.left = 0;
    style.width = "".concat(contentWidth, "px");
    style.height = "".concat(contentHeight, "px"); // use transform

    style.transform = "matrix3d(".concat(object.getWorldTransform().join(','), ")");

    if (anchor) {
      style.transform += " translate(".concat(anchor[0] * 100, "%, ").concat(anchor[0] * 100, "%)");
    } // use unparsed transform origin


    if (object.style.transformOrigin) {
      style['transform-origin'] = object.style.transformOrigin;
    } // z-index


    style['z-index'] = zIndex; // visibility

    style.visibility = visibility; // opacity

    style.opacity = opacity; // backgroundColor

    if (fill) {
      var color = '';

      if (fill.type === PARSED_COLOR_TYPE.Constant) {
        color = fill.formatted;
      } else if (fill.type === PARSED_COLOR_TYPE.LinearGradient) {
        var steps = fill.value.steps.map(function (cur) {
          //  ['0', '#ffffff'],
          return "".concat(cur[1], " ").concat(Number(cur[0]) * 100, "%");
        }).join(','); // @see https://developer.mozilla.org/en-US/docs/Web/CSS/gradient/linear-gradient()

        color = "linear-gradient(to right, ".concat(steps, ");");
      } else if (fill.type === PARSED_COLOR_TYPE.RadialGradient) {} else if (fill.type === PARSED_COLOR_TYPE.Pattern) {}

      style.background = color;
    } // border


    style['border-width'] = "".concat(lineWidth.value, "px");

    if (stroke && stroke.type === PARSED_COLOR_TYPE.Constant) {
      style['border-color'] = stroke.formatted;
      style['border-style'] = 'solid';
    }

    if (lineDash) {
      style['border-style'] = 'dashed';
    } // filters


    if (object.style.filter) {
      // use unparsed filter directly
      style.filter = object.style.filter;
    }

    if (className) {
      if (Array.isArray(className)) {
        className.forEach(function (c) {
          $el.classList.add(c);
        });
      } else {
        $el.classList.add(className);
      }
    }

    $el.setAttribute('style', Object.keys(style).map(function (key) {
      return "".concat(key, ":").concat(style[key]);
    }).join(';') + initialStyle);
  };

  var HTMLRenderingPlugin_1;
  HTMLRenderingPlugin.tag = 'HTMLRenderingPlugin';

  __decorate([inject(ContextService), __metadata("design:type", Object)], HTMLRenderingPlugin.prototype, "contextService", void 0);

  __decorate([inject(RenderingContext), __metadata("design:type", Object)], HTMLRenderingPlugin.prototype, "renderingContext", void 0);

  HTMLRenderingPlugin = HTMLRenderingPlugin_1 = __decorate([singleton({
    contrib: RenderingPluginContribution
  })], HTMLRenderingPlugin);
  return HTMLRenderingPlugin;
}();

export { HTMLRenderingPlugin };
